==> faketooth-0.0.24.tar.gz: ios/Vendor/Faketooth/Demo/Demo/Features/Exploring/CharacteristicView.swift <==
//
//  CharacteristicView.swift
//  Faketooth
//
//  Created by Max Rozdobudko on 6/17/20.
//  Copyright © 2020 Max Rozdobudko. All rights reserved.
//

import SwiftUI
import Faketooth

struct CharacteristicView: View {

    @ObservedObject var viewModel: CharacteristicViewModel

    @State private var values: String = ""
    var body: some View {
        VStack {
            Text("\(viewModel.characteristicUUID)")
                .font(.headline)
            GeometryReader { geometry in
                VStack {
                    Text("Service: \(self.viewModel.serviceUUID)")
                    Text("Values:")
                    List(self.viewModel.values, id: \.self) { value in
                        Text(value)
                    }
                    .frame(width: geometry.size.width)
                    if self.viewModel.isReadSupported {
                        Button(action: self.onRead) {
                            Text("Read")
                        }
                    }
                }
            }
        }
        .onAppear(perform: viewModel.enter)
        .onDisappear(perform: viewModel.exit)
    }

    func onRead() {
        viewModel.readValue()
    }
}

struct CharacteristicView_Previews: PreviewProvider {
    static var previews: some View {
        CharacteristicView(viewModel:
            CharacteristicViewModel(characteristic:
                FaketoothCharacteristic(
                    uuid: CBUUID(),
                    valueProducer: { nil },
                    properties: CBCharacteristicProperties.read
                )
            )
        )
    }
}

==> faketooth-0.1.1.tar.gz: ios/Vendor/Faketooth/Demo/Demo/Features/Exploring/CharacteristicView.swift <==
//
//  CharacteristicView.swift
//  Faketooth
//
//  Created by Max Rozdobudko on 6/17/20.
//  Copyright © 2020 Max Rozdobudko. All rights reserved.
//

import SwiftUI
import Faketooth

struct CharacteristicView: View {

    @ObservedObject var viewModel: CharacteristicViewModel

    @State private var values: String = ""
    var body: some View {
        VStack {
            Text("\(viewModel.characteristicUUID)")
                .font(.headline)
            GeometryReader { geometry in
                VStack {
                    Text("Service: \(self.viewModel.serviceUUID)")
                    Text("Values:")
                    List(self.viewModel.values, id: \.self) { value in
                        Text(value)
                    }
                    .frame(width: geometry.size.width)
                    if self.viewModel.isReadSupported {
                        Button(action: self.onRead) {
                            Text("Read")
                        }
                    }
                    if self.viewModel.isWriteSupported {
                        Button(action: self.onWrite) {
                            Text("Write")
                        }
                    }
                }
            }
        }
        .onAppear(perform: viewModel.enter)
        .onDisappear(perform: viewModel.exit)
    }

    func onRead() {
        viewModel.readValue()
    }

    func onWrite() {
        viewModel.writeValue();
    }
}

struct CharacteristicView_Previews: PreviewProvider {
    static var previews: some View {
        CharacteristicView(viewModel:
            CharacteristicViewModel(characteristic:
                FaketoothCharacteristic(
                    uuid: CBUUID(),
                    properties: CBCharacteristicProperties.read,
                    valueProducer: { nil }
                )
            )
        )
    }
}
